@@ -39,7 +39,7 @@ class Consumer(Worker):
         }
 
     def __init__(self):
-        super().__init__()
+        Worker.__init__(self)
         self.queue = Queue(self.exceeded_size)
 
 
