@@ -16,7 +16,15 @@ class Warehut:
     producer: list[Worker]
     consumers: list[Worker]
 
-    def __init__(self, worker_types: Sequence[type[Worker]], *args, **kwargs):
+    def __init__(self, worker_types: Sequence[type[Worker]],
+            pro_kwargs: dict = None, con_kwargs: dict = None,
+            hyb_kwargs: dict = None
+    ):
+        # Initialize keyword arguments for each type
+        pro_kwargs = pro_kwargs or {}
+        con_kwargs = con_kwargs or {}
+        hyb_kwargs = hyb_kwargs or {**con_kwargs, **pro_kwargs}
+
         # Separate worker types
         producers, consumers, hybrids = [], [], []
 
@@ -29,9 +37,9 @@ class Warehut:
                 consumers.append(w)
 
         # Initialize consumers and producers
-        self.consumers = [w(*args, **kwargs) for w in consumers]
-        self.producers  = [w(self.consumers, *args, **kwargs) for w in producers]
-        self.hybrids = [w(self.consumers, *args, **kwargs) for w in hybrids]
+        self.consumers = [w(**con_kwargs) for w in consumers]
+        self.producers  = [w(self.consumers, **pro_kwargs) for w in producers]
+        self.hybrids = [w(self.consumers, **hyb_kwargs) for w in hybrids]
 
         # Add hybrids to both consumers and producers
         self.consumers.extend(self.hybrids)
